@@ -6,7 +6,7 @@ use feature 'say';
 use base 'Padre::Task';
 
 use Carp;
-use IPC::Run;
+use IPC::Run3;
 use Storable;
 use File::Basename;
 use File::Spec;
@@ -32,7 +32,7 @@ sub prepare {
 
     # assign a place in the work queue
     if($thread_running) {
-	return "break";
+        return "break";
     }
     $thread_running = 1;
     return 1;
@@ -73,24 +73,23 @@ sub finish {
     my $doc = $self->{main_thread_only}{document};
     my $editor = $self->{main_thread_only}{editor};
     if($self->{tokens}) {
-	$doc->remove_color;
-	my @tokens = @{$self->{tokens}};
-	for my $htoken (@tokens) {
-	    my %token = %{$htoken};
-	    my $color = $colors{ $token{rule} };
-	    if($color) {
-		my $len = length $token{buffer};
-		my $start = $token{last_pos} - $len;
-		$editor->StartStyling($start, $color);
-		$editor->SetStyling($len, $color);
-	    }
-	}
-	$doc->{issues} = [];
+        $doc->remove_color;
+        my @tokens = @{$self->{tokens}};
+        for my $htoken (@tokens) {
+            my %token = %{$htoken};
+            my $color = $colors{ $token{rule} };
+            if($color) {
+                my $len = length $token{buffer};
+                my $start = $token{last_pos} - $len;
+                $editor->StartStyling($start, $color);
+                $editor->SetStyling($len, $color);
+            }
+        }
+        $doc->{issues} = [];
     } elsif($self->{issues}) {
-	# pass errors/warnings to document...
-	$doc->{issues} = $self->{issues};
+        # pass errors/warnings to document...
+        $doc->{issues} = $self->{issues};
     }
-    # cleanup!
 
     # finished here
     $thread_running = 0;
@@ -106,27 +105,27 @@ sub run {
 
     # construct the command
     my @cmd = ( Padre->perl_interpreter,
-	Cwd::realpath(File::Spec->join(File::Basename::dirname(__FILE__),'p6tokens.pl')));
+        Cwd::realpath(File::Spec->join(File::Basename::dirname(__FILE__),'p6tokens.pl')));
 
-    my ($in, $out, $err) = ($text,'',undef);
-    my $h = IPC::Run::run(\@cmd, \$in, \$out, \$err);
+    my ($out, $err) = ('',undef);
+    run3 \@cmd, \$text, \$out, \$err;
     if($err) {
-	my @messages = split /\n/, $err;
-	my ($lineno,$severity);
-	my $issues = [];
-	for my $msg (@messages) {
-	    if($msg =~ /error\s.+?line (\d+):$/i) {
-		#an error
-		($lineno,$severity) = ($1, 'E');
-	    } elsif($msg =~ /line (\d+):$/i) {
-		#a warning
-		($lineno,$severity) = ($1, 'W');
-	    }
-	    if($lineno) {
-		push @{$issues}, { line => $lineno, msg => $msg, severity => $severity, };
-	    }
-	}
-	$self->{issues} = $issues;
+        my @messages = split /\n/, $err;
+        my ($lineno,$severity);
+        my $issues = [];
+        for my $msg (@messages) {
+            if($msg =~ /error\s.+?line (\d+):$/i) {
+                #an error
+                ($lineno,$severity) = ($1, 'E');
+            } elsif($msg =~ /line (\d+):$/i) {
+                #a warning
+                ($lineno,$severity) = ($1, 'W');
+            }
+            if($lineno) {
+                push @{$issues}, { line => $lineno, msg => $msg, severity => $severity, };
+            }
+        }
+        $self->{issues} = $issues;
     } else {
         $self->{tokens} = Storable::thaw($out);
     }
